@@ -21,6 +21,9 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/12] STATUS_COMMUNITYをビットフラグ
+ -      [2007/02/12] VISIBILITYをビットフラグ
+ -      [2007/02/02] コンテンツ記事の表示開始年を追加
  -      [2007/02/02] 最新情報表示期間定義を追加
  -      [2007/02/02] 日記コメント定義を追加
  -      [2007/01/29] 日記のフォーマット定義を追加
@@ -147,9 +150,11 @@ define('SMARTY_CONFIG_DIR', SMARTY_DIR.'configs'.DIRECTORY_SEPARATOR);  // Smart
 define('SNS_ACC_ADMIN', 1);                                         // 管理者ユーザーID
 define('SNS_ACC_GHOST', 2);                                         // ゴーストユーザーID
 define('WAP_START_AGE', 1940);                                      // 年齢初期値
+define('WAP_START_YEAR', 2006);                                     // スタート年
 define('WAP_DEFAULT_NUMBER_BLOG',2);                                // パスインフォ引数の開始番号
 define('ALLOWABLE_TAGS',
-    '<a><br><em><font><img><li><ol><span><strike><strong><u><ul>'); // 入力を許可するタグ
+    '<a><br><em><font><img><li><ol><span>'.
+    '<strike><strong><u><ul><p><div>');                             // 入力を許可するタグ
 define('WAP_TIME_LIMIT',3600);                                      // タイムアウト時間を設定
 
 /* ---------------------------------------- */
@@ -195,14 +200,17 @@ define('MESSAGE_FLAG_RETURN',3);                                    // 返信メ
 
 /* ---------------------------------------- */
 /* 表示の権限 */
-define('VISIBILITY_ROUGH',    1);                                   // 下書き
-define('VISIBILITY_PUBLIC',   2);                                   // ネット上に公開
-define('VISIBILITY_PROTECTED',3);                                   // 会員に公開
-define('VISIBILITY_FRIEND',   4);                                   // お友達に公開
-define('VISIBILITY_PRIVATE',  4);                                   // メンバーに公開
-define('VISIBILITY_HIDDEN',   5);                                   // 公開しない
+define('VISIBILITY_HIDDEN',   0x01);                                // 公開しない
+define('VISIBILITY_PUBLIC',   0x02);                                // ネット上に公開
+define('VISIBILITY_PROTECTED',0x04);                                // 会員に公開
+define('VISIBILITY_FRIEND',   0x08);                                // お友達に公開
+define('VISIBILITY_PRIVATE',  0x08);                                // メンバーに公開
+
+define('VISIBILITY_OPEN',     0x06);                                // 会員に公開まで
+define('VISIBILITY_CLOSE',    0x0E);                                // お友達に公開まで
+
+define('VISIBILITY_ALL',      0xFF);                                // 全部
 
-define('VISIBILITY_LABEL_ROUGH',    '下書き');
 define('VISIBILITY_LABEL_PUBLIC',   'ネット上に公開');
 define('VISIBILITY_LABEL_PROTECTED','会員に公開');
 define('VISIBILITY_LABEL_FRIEND',   'お友達に公開');
@@ -251,6 +259,8 @@ define('STATUS_PHOTO_MAIN', 1);                                     // メイン
 /* トピックの状態 */
 define('STATUS_TOPIC_BULLETIN', 1);                                 // 掲示板用
 define('STATUS_TOPIC_EVENT',    2);                                 // イベント用
+define('STATUS_TOPIC_ITEM',     3);                                 // コミュニティ記事
+define('STATUS_TOPIC_ENQUETE',  4);                                 // コミュニティアンケート
 
 /* ---------------------------------------- */
 /* レビューのタイプ */
@@ -258,17 +268,19 @@ define('REVIEW_TYPE_AMAZON',   1);                                  // アマゾ
 
 /* ---------------------------------------- */
 /* 名簿の状態 */
-define('STATUS_COMMUNITY_ADMIN',   1);                              // 管理人
-define('STATUS_COMMUNITY_MEMBER',  2);                              // メンバー
-define('STATUS_COMMUNITY_CHANGE',  3);                              // 管理人交代
-define('STATUS_COMMUNITY_REFUSAL', 4);                              // 拒絶
-define('STATUS_COMMUNITY_REQUEST', 6);                              // 参加希望者
+define('STATUS_COMMUNITY_ADMIN',   0x01);                           // 管理人
+define('STATUS_COMMUNITY_MEMBER',  0x02);                           // メンバー
+define('STATUS_COMMUNITY_REFUSAL', 0x04);                           // 拒絶
+define('STATUS_COMMUNITY_REQUEST', 0x08);                           // 参加希望者
+define('STATUS_COMMUNITY_CHANGE',  0x10);                           // 管理人交代
+
+define('STATUS_COMMUNITY_MEMBERS', 0x1B);                           // メンバー全部
 
 define('STATUS_COMMUNITY_LABEL_ADMIN',  '管理人');
 define('STATUS_COMMUNITY_LABEL_MEMBER', 'メンバー');
-define('STATUS_COMMUNITY_LABEL_CHANGE', '管理人交代');
 define('STATUS_COMMUNITY_LABEL_REFUSAL','拒絶');
 define('STATUS_COMMUNITY_LABEL_REQUEST','参加希望者');
+define('STATUS_COMMUNITY_LABEL_CHANGE', '管理人交代');
 
 /* ---------------------------------------- */
 /* フォームの種類 */
@@ -346,8 +358,8 @@ define('RKT_ACC_ADMIN',WAP_ACC_ADMIN);                              // アクセ
 define('RKT_ACC_DEFAULT',WAP_ACC_GUEST);                            // アクセス権限:デフォルト
 define('RKT_ACCOUNT_CLASS','account');                              // アカウントクラス名
 define('RKT_DB_DRIVER', WAP_DB_DRIVER);                             // デフォルトDBドライバ
-define('RKT_DSN', WAP_DB_DRIVER.':'.SNS_DB_FILE);                   // デフォルトDB DSN
-define('RKT_BLOB_DSN', WAP_DB_DRIVER.':'.BLOB_DB_FILE);             // デフォルトDB BLOB DSN
+define('RKT_DSN', WAP_DB_DRIVER.':'.DB_NAME_HOST);                  // デフォルトDB DSN
+define('RKT_BLOB_DSN', WAP_DB_DRIVER.':'.DB_NAME_HOST);             // デフォルトDB BLOB DSN
 define('RKT_DB_USER',  WAP_DB_USER);                                // デフォルトDBユーザー
 define('RKT_DB_PASSWD',WAP_DB_PASSWD);                              // デフォルトDBパスワード
 define('RKT_TBL_ACCOUNT',DB_PREFIX.'act_account');                  // アカウントテーブル名
