@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/13] 公開レベルを保持
  -      [2006/09/20] $this->base['uri_separator']を追加
  -      [2006/08/28] あしあと処理をメンバ関数に所持
  -      [2006/08/26] 友達情報をメンバ変数に所持
@@ -67,6 +68,12 @@ class WAP_friend extends RKT_webapp
      */
     var $ref_friend = 0;
 
+    /**
+     * 表示公開レベル
+     * @var integer
+     */
+    var $visibility = VISIBILITY_PUBLIC;
+
     /**
      * コンストラクタ
      *
@@ -103,11 +110,14 @@ class WAP_friend extends RKT_webapp
         }
 
         if ($this->breaker()){
-            header('Location: '.HTTP_ACTION.'private/home/');
+            header('Location: '.HTTP_ACTION.'private/home/nobody/');
             exit();
         }
+        $this->set_visibility();
+
         $this->base['ref_friend'] = $this->ref_friend;
         $this->base['friend']     = $this->friend;
+        $this->base['visibility'] = $this->visibility;
     }
 
     /**
@@ -411,6 +421,68 @@ class WAP_friend extends RKT_webapp
             $this->send_mail($result['footprint']);
         }
     }
+
+    /**
+     * 公開レベルの設定
+     *
+     * @access private
+     * @return void
+     */
+    function set_visibility()
+    {
+        $this->visibility  = VISIBILITY_PUBLIC;
+        $this->visibility |= VISIBILITY_PROTECTED;
+        $sql=
+            'SELECT '.
+                'status '.
+            'FROM '.
+                DB_PREFIX.'fri_friends '.
+            'WHERE '.
+                'ref_account ='.$this->ref_friend.' AND '.
+                'ref_friend = '.$this->account['id'];
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+        if (empty($result['status'])){
+            return ;
+        }
+
+        $this->visibility |= VISIBILITY_FRIEND;
+    }
+
+    /**
+     * 友達の友達か？
+     *
+     * @access private
+     * @return array
+     */
+    function is_acquaintance()
+    {
+        $sql=
+            'SELECT '.
+                'direct.ref_friend '.
+            'FROM '.
+                DB_PREFIX.'fri_friends direct,'.
+                DB_PREFIX.'fri_friends near '.
+            'WHERE '.
+                'direct.ref_friend = near.ref_account AND '.
+                'direct.avail = '.AVAIL_ENABLE.' AND '.
+                'direct.status & '.STATUS_FRIEND_CONNECT.' AND '.
+                'direct.ref_account = '.$this->account['id'].' AND '.
+                'near.avail = '.AVAIL_ENABLE.' AND '.
+                'near.status & '.STATUS_FRIEND_CONNECT.' AND '.
+                'near.ref_friend = '.$this->ref_friend;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+        
+        if (empty($result['ref_friend'])){
+            return false;
+        }
+        return $result['ref_friend'];
+    }
 }
 // WAP_friendの終了
 ?>
