@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/13] 公開レベルをビットフラグに対応
+ -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2007/02/03] 市区町村条件指定エラーの修正
  -      [2006/08/29] 表示整形の不具合修正
  -      [2006/08/27] 基礎情報を親クラスから引っ張るように修正
@@ -163,50 +165,6 @@ class webapp extends WAP_friend
         return $result;
     }
 
-    /**
-     * フラグの設定
-     *
-     * @access private
-     * @return void
-     */
-    function set_flag(&$value)
-    {
-        $is_friend = $this->isFriend();
-        $flag = array();
-
-        $flag = ($value['name_flag'] == VISIBILITY_FRIEND)?$is_friend:true;
-        $flag = ($value['name_flag'] == VISIBILITY_HIDDEN)?false:$flag;
-        $value['name_flag'] = $flag;
-
-        $flag = ($value['prefecture_flag'] == VISIBILITY_FRIEND)?$is_friend:true;
-        $flag = ($value['prefecture_flag'] == VISIBILITY_HIDDEN)?false:$flag;
-        $value['prefecture_flag'] = $flag;
-
-        $flag = ($value['blood_flag'] == VISIBILITY_FRIEND)?$is_friend:true;
-        $flag = ($value['blood_flag'] == VISIBILITY_HIDDEN)?false:$flag;
-        $value['blood_flag'] = $flag;
-
-        $flag = ($value['birthday_flag'] == VISIBILITY_FRIEND)?$is_friend:true;
-        $flag = ($value['birthday_flag'] == VISIBILITY_HIDDEN)?false:$flag;
-        $value['birthday_flag'] = $flag;
-
-        $flag = ($value['age_flag'] == VISIBILITY_FRIEND)?$is_friend:true;
-        $flag = ($value['age_flag'] == VISIBILITY_HIDDEN)?false:$flag;
-        $value['age_flag'] = $flag;
-
-        $flag = ($value['married_flag'] == VISIBILITY_FRIEND)?$is_friend:true;
-        $flag = ($value['married_flag'] == VISIBILITY_HIDDEN)?false:$flag;
-        $value['married_flag'] = $flag;
-
-        $flag = ($value['hometown_flag'] == VISIBILITY_FRIEND)?$is_friend:true;
-        $flag = ($value['hometown_flag'] == VISIBILITY_HIDDEN)?false:$flag;
-        $value['hometown_flag'] = $flag;
-
-        $flag = ($value['sex_flag'] == VISIBILITY_FRIEND)?$is_friend:true;
-        $flag = ($value['sex_flag'] == VISIBILITY_HIDDEN)?false:$flag;
-        $value['sex_flag'] = $flag;
-    }
-
     /**
      * プロフィールの設定
      *
@@ -272,8 +230,6 @@ class webapp extends WAP_friend
             exit();
         }
         
-        $this->set_flag($result);
-
         $this->Assign('profile',$result);
     }
 
@@ -324,11 +280,6 @@ class webapp extends WAP_friend
      */
     function get_item($ref_enquete, $form_type)
     {
-        /* 友達か？ */
-        $where = '';
-        if ($this->isFriend()){
-            $where = ' OR con.visibility = '.VISIBILITY_FRIEND;
-        }
         $sql=
             'SELECT '.
                 'con.ref_enquete as ref_enquete,'.
@@ -339,9 +290,7 @@ class webapp extends WAP_friend
                     'LEFT JOIN '.DB_PREFIX.'act_item itm '.
                     'ON itm.id = con.ref_item '.
             'WHERE '.
-                '(con.visibility = '.VISIBILITY_PUBLIC.' OR '.
-                 'con.visibility = '.VISIBILITY_PROTECTED.
-                $where.') AND '.
+                sql_query::bitFlag('con.visibility & '.$this->visibility).' AND '.
                 'con.ref_enquete = '.$ref_enquete.' AND '.
                 'con.ref_account = '.$this->ref_friend;
         $stmt = $this->objdb->prepare($sql); 
@@ -368,11 +317,6 @@ class webapp extends WAP_friend
      */
     function get_select($ref_enquete)
     {
-        /* 友達か？ */
-        $where = '';
-        if ($this->isFriend()){
-            $where = ' OR sel.visibility = '.VISIBILITY_FRIEND;
-        }
         $sql=
             'SELECT '.
                 'itm.item as item '.
@@ -382,9 +326,7 @@ class webapp extends WAP_friend
             'WHERE '.
                 'itm.id = sel.ref_item AND '.
                 'sel.ref_enquete = '.$ref_enquete.' AND '.
-                '(sel.visibility = '.VISIBILITY_PUBLIC.' OR '.
-                 'sel.visibility = '.VISIBILITY_PROTECTED.
-                $where.') AND '.
+                sql_query::bitFlag('sel.visibility & '.$this->visibility).' AND '.
                 'sel.ref_account = '.$this->ref_friend;
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
@@ -500,9 +442,7 @@ class webapp extends WAP_friend
             'WHERE '.
                 'com.id = nms.ref_community AND '.
                 'com.avail = '.AVAIL_ENABLE.' AND '.
-                '(nms.status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                 'nms.status = '.STATUS_COMMUNITY_CHANGE.' OR '.
-                 'nms.status = '.STATUS_COMMUNITY_ADMIN.') AND '.
+                sql_query::bitFlag('nms.status & '.STATUS_COMMUNITY_MEMBERS).' AND '.
                 'nms.ref_account = '.$this->ref_friend.' '.
             'ORDER BY '.
                 'nms.modify '.
@@ -561,9 +501,7 @@ class webapp extends WAP_friend
                 DB_PREFIX.'com_names '.
             'WHERE '.
                 'ref_account = '.$this->ref_friend. ' AND '.
-                '(status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                 'status = '.STATUS_COMMUNITY_CHANGE.' OR '.
-                 'status = '.STATUS_COMMUNITY_ADMIN.')';
+                sql_query::bitFlag('status & '.STATUS_COMMUNITY_MEMBERS);
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
@@ -645,12 +583,6 @@ class webapp extends WAP_friend
      */
     function set_forum()
     {
-        /* 友達か？ */
-        $where = '';
-        if ($this->isFriend()){
-            $where = 'OR visibility = '.VISIBILITY_FRIEND.' ';
-        }
-
         $sql=
             'SELECT '.
                 'id,'.
@@ -661,8 +593,7 @@ class webapp extends WAP_friend
                 DB_PREFIX.'frm_topic '.
             'WHERE '.
                 'ref_account = '.$this->ref_friend.' AND '.
-                '(visibility = '.VISIBILITY_PROTECTED.' '.
-                $where.') '.
+                sql_query::bitFlag('visibility & '.$this->visibility).' '.
             'ORDER BY '.
                 'modify DESC '.
             'LIMIT 5';
