@@ -2,7 +2,7 @@
 /* ========================================================================
  - [modules/private/edit/relation.php]
  -      各種認証
- -      Copyright (c) 2006 Yujiro Takahashi
+ -      Copyright (c) 2006-2007 Yujiro Takahashi
  - ライセンス:
  -      This program is free software; you can redistribute it and/or
  -      modify it under the terms of the GNU General Public License
@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/03/11] 表示情報がない時の処理を追加
+ -      [2007/02/13] コミュニティ参加人数の更新処理を追加
  -      [2006/07/10] 作成
  - ======================================================================== */
 
@@ -63,6 +65,12 @@ class webapp extends WAP_private
      */
     var $status = 0;
 
+    /**
+     * データなし
+     * @var integer
+     */
+    var $no_data = true;
+
     /**
      * 実行処理
      *
@@ -90,6 +98,8 @@ class webapp extends WAP_private
         $this->set_friends();
         $this->set_change();
         $this->set_entry();
+
+        $this->Assign('no_data', $this->no_data);
     }
 
     /**
@@ -130,6 +140,10 @@ class webapp extends WAP_private
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return ;
+        }
+        $this->no_data = false;
 
         $this->Assign('friends', $result);
     }
@@ -334,6 +348,10 @@ class webapp extends WAP_private
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return ;
+        }
+        $this->no_data = false;
 
         $this->Assign('changes', $result);
     }
@@ -488,6 +506,10 @@ class webapp extends WAP_private
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return ;
+        }
+        $this->no_data = false;
 
         $this->Assign('entrys', $result);
     }
@@ -537,19 +559,53 @@ class webapp extends WAP_private
             'UPDATE '.
                 DB_PREFIX.'com_names '.
             ' SET '.
-                'status='.$this->status.' '.
+                'status = '.$this->status.' '.
             ' WHERE '.
                 'id = '.$this->ref_entry;
         $result = $this->objdb->exec($sql);
 
         /* アクション処理 */
         if ($result){
+            $this->update_total($infos);
             $this->send_entry($infos);
             header('Location: '.HTTP_ACTION.'private/edit/relation/'.WAP_URI_SEPARATOR.'updated=1');
             exit();
         }        
     }
 
+    /**
+     * 会員総数を更新
+     *
+     * @access private
+     * @param array $infos
+     * @return void
+     */
+    function update_total($infos)
+    {
+        $sql = 
+            'SELECT '.
+                'count(id) as total '.
+            'FROM '.
+                DB_PREFIX.'com_names '.
+            'WHERE '.
+                'ref_community = '.$infos['id']. ' AND '.
+                sql_query::bitFlag('status & '.STATUS_COMMUNITY_MEMBERS);
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+        $total = empty($result['total'])?0:$result['total'];
+
+        $sql =
+            'UPDATE '.
+                DB_PREFIX.'com_community '.
+            'SET '.
+                'total = '.$total.' '.
+            'WHERE '.
+                'id = '.$infos['id'];
+        $this->objdb->exec($sql);
+    }
+
     /**
      * コミュニティ参加通知メール
      *
