@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2006/07/10] 表示整形の不具合修正
  -      [2006/08/27] 基礎情報を親クラスから引っ張るように修正
  -      [2006/07/10] 作成
@@ -336,9 +337,7 @@ class webapp extends WAP_private
             'WHERE '.
                 'com.id = nms.ref_community AND '.
                 'com.avail = '.AVAIL_ENABLE.' AND '.
-                '(nms.status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                'nms.status = '.STATUS_COMMUNITY_CHANGE.' OR '.
-                'nms.status = '.STATUS_COMMUNITY_ADMIN.') AND '.
+                sql_query::bitFlag('nms.status & '.STATUS_COMMUNITY_MEMBERS).' AND '.
                 'nms.ref_account = '.$this->account['id'].' '.
             'ORDER BY '.
                 'nms.modify '.
@@ -397,9 +396,7 @@ class webapp extends WAP_private
                 DB_PREFIX.'com_names '.
             'WHERE '.
                 'ref_account = '.$this->account['id'].' AND '.
-                '(status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                 'status = '.STATUS_COMMUNITY_CHANGE.' OR '.
-                 'status = '.STATUS_COMMUNITY_ADMIN.')';
+                sql_query::bitFlag('status & '.STATUS_COMMUNITY_MEMBERS);
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
