@@ -1,6 +1,6 @@
 -- ========================================================================
 -- [works/sqls/mysql.sql]
--- 		SQLite用テーブル定義
+-- 		MySQL4用テーブル定義
 --      Copyright (c) 2006 Yujiro Takahashi
 -- ライセンス:
 --      This program is free software; you can redistribute it and/or
@@ -201,9 +201,9 @@ CREATE TABLE `sns_act_account` (
   `cellular_hash` varchar(32),
   `news` int(11),
   `mailing` int(11),
-  `footprint` int(11),
-  `total` int(11),
-  `friend_number` int(11),
+  `footprint` int(11) default '0',
+  `total` int(11) default '0',
+  `friend_number` int(11) default '0',
   `block` text,
   PRIMARY KEY  (`id`),
   UNIQUE (`email_hash`),
@@ -411,6 +411,7 @@ CREATE TABLE `sns_dia_entry` (
   `ref_account` int(11) NOT NULL,
   `visibility` int(11) NOT NULL,
   `format` int(11) NOT NULL,
+  `post` int(11) default '0',
   `link` varchar(255),
   `subject` varchar(255) NOT NULL,
   `body` text NOT NULL,
@@ -659,7 +660,7 @@ CREATE TABLE `sns_frm_topic` (
   `high_age` int(11),
   `ref_married` int(11),
   `ref_hometown` int(11),
-  `post` int(11),
+  `post` int(11) default '0',
   `topic` varchar(255) NOT NULL,
   `comment` text NOT NULL,
   PRIMARY KEY  (`id`)
@@ -826,6 +827,7 @@ CREATE TABLE `sns_com_topic` (
   `sub_locale` varchar(255),
   `topic` varchar(255) NOT NULL,
   `comment` text NOT NULL,
+  `post` int(11) default '0',
   PRIMARY KEY  (`id`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
@@ -857,6 +859,34 @@ CREATE TABLE `sns_com_entry` (
   UNIQUE (`ref_community`,`ref_topic`,`ref_account`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
+-- 
+-- アンケートオプション
+-- 
+CREATE TABLE `sns_com_option` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `ref_community` int(11) NOT NULL,
+  `ref_topic` int(11) NOT NULL,
+  `sort` int(11) NOT NULL,
+  `item` varchar(255) NOT NULL,
+  PRIMARY KEY  (`id`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
+
+-- 
+-- アンケートの選択結果
+-- 
+CREATE TABLE `sns_com_itmselect` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `regist_date` timestamp NOT NULL,
+  `ref_community` int(11) NOT NULL,
+  `ref_topic` int(11) NOT NULL,
+  `ref_account` int(11) NOT NULL,
+  `ref_option` int(11) NOT NULL,
+  `comment` text,
+  PRIMARY KEY  (`id`),
+  UNIQUE (`ref_topic`,`ref_account`,`ref_option`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
+
 -- 
 -- コミュニティの画像
 -- 
@@ -1001,7 +1031,7 @@ CREATE TABLE `sns_rev_item` (
   `modify` timestamp NOT NULL,
   `ref_category` int(11) NOT NULL,
   `total` float,
-  `post` int(11),
+  `post` int(11) default '0',
   `url` varchar(255) NOT NULL,
   `asin` varchar(128) NOT NULL,
   `name` text NOT NULL,
