@@ -211,9 +211,9 @@ CREATE TABLE sns_act_account (
   cellular_hash varchar(32),
   news integer,
   mailing integer,
-  footprint integer,
-  total integer,
-  friend_number integer,
+  footprint integer DEFAULT 0,
+  total integer DEFAULT 0,
+  friend_number integer DEFAULT 0,
   block text,
   PRIMARY KEY  (id),
   UNIQUE (email_hash),
@@ -433,6 +433,7 @@ CREATE TABLE sns_dia_entry (
   ref_account integer NOT NULL,
   visibility integer NOT NULL,
   format integer NOT NULL,
+  post integer DEFAULT 0,
   link varchar(255),
   subject varchar(255) NOT NULL,
   body text NOT NULL,
@@ -697,7 +698,7 @@ CREATE TABLE sns_frm_topic (
   high_age integer,
   ref_married integer,
   ref_hometown integer,
-  post integer,
+  post integer DEFAULT 0,
   topic varchar(255) NOT NULL,
   comment text NOT NULL,
   PRIMARY KEY  (id)
@@ -875,6 +876,7 @@ CREATE TABLE sns_com_topic (
   sub_locale varchar(255),
   topic varchar(255) NOT NULL,
   comment text NOT NULL,
+  post integer DEFAULT 0,
   PRIMARY KEY  (id)
 );
 
@@ -908,6 +910,36 @@ CREATE TABLE sns_com_entry (
   UNIQUE (ref_community,ref_topic,ref_account)
 );
 
+-- 
+-- アンケートオプション
+-- 
+CREATE SEQUENCE seq_sns_com_option start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
+CREATE TABLE sns_com_option (
+  id integer DEFAULT nextval('seq_sns_com_option'::text) NOT NULL,
+  ref_community integer NOT NULL,
+  ref_topic integer NOT NULL,
+  sort integer NOT NULL,
+  item varchar(255) NOT NULL,
+  PRIMARY KEY  (id)
+);
+
+-- 
+-- アンケートの選択結果
+-- 
+CREATE SEQUENCE seq_sns_com_itmselect start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
+CREATE TABLE sns_com_itmselect (
+  id integer DEFAULT nextval('seq_sns_com_itmselect'::text) NOT NULL,
+  modify timestamp without time zone NOT NULL,
+  regist_date timestamp without time zone NOT NULL,
+  ref_community integer NOT NULL,
+  ref_topic integer NOT NULL,
+  ref_account integer NOT NULL,
+  ref_option integer NOT NULL,
+  comment text,
+  PRIMARY KEY  (id),
+  UNIQUE (ref_topic,ref_account,ref_option)
+);
+
 -- 
 -- コミュニティの画像
 -- 
@@ -1064,7 +1096,7 @@ CREATE TABLE sns_rev_item (
   modify timestamp without time zone NOT NULL,
   ref_category integer NOT NULL,
   total float,
-  post integer,
+  post integer DEFAULT 0,
   url varchar(255) NOT NULL,
   asin varchar(128) NOT NULL,
   name text NOT NULL,
