@@ -185,9 +185,9 @@ CREATE TABLE 'sns_act_account' (
   'cellular_hash' varchar(32),
   'news' integer,
   'mailing' integer,
-  'footprint' integer,
-  'total' integer,
-  'friend_number' integer,
+  'footprint' integer default '0',
+  'total' integer default '0',
+  'friend_number' integer default '0',
   'block' text,
   PRIMARY KEY  ('id'),
   UNIQUE ('email_hash'),
@@ -396,6 +396,7 @@ CREATE TABLE 'sns_dia_entry' (
   'ref_account' integer NOT NULL,
   'visibility' integer NOT NULL,
   'format' integer NOT NULL,
+  'post' integer default '0',
   'link' varchar(255),
   'subject' varchar(255) NOT NULL,
   'body' text NOT NULL,
@@ -644,7 +645,7 @@ CREATE TABLE 'sns_frm_topic' (
   'high_age' integer,
   'ref_married' integer,
   'ref_hometown' integer,
-  'post' integer,
+  'post' integer default '0',
   'topic' varchar(255) NOT NULL,
   'comment' text NOT NULL,
   PRIMARY KEY  ('id')
@@ -812,6 +813,7 @@ CREATE TABLE 'sns_com_topic' (
   'sub_locale' varchar(255),
   'topic' varchar(255) NOT NULL,
   'comment' text NOT NULL,
+  'post' integer default '0',
   PRIMARY KEY  ('id')
 );
 
@@ -843,6 +845,34 @@ CREATE TABLE 'sns_com_entry' (
   UNIQUE ('ref_community','ref_topic','ref_account')
 );
 
+-- 
+-- アンケートオプション
+-- 
+CREATE TABLE 'sns_com_option' (
+  'id' integer NOT NULL,
+  'ref_community' integer NOT NULL,
+  'ref_topic' integer NOT NULL,
+  'sort' integer NOT NULL,
+  'item' varchar(255) NOT NULL,
+  PRIMARY KEY  ('id')
+);
+
+-- 
+-- アンケートの選択結果
+-- 
+CREATE TABLE 'sns_com_itmselect' (
+  'id' integer NOT NULL,
+  'modify' timestamp NOT NULL,
+  'regist_date' timestamp NOT NULL,
+  'ref_community' integer NOT NULL,
+  'ref_topic' integer NOT NULL,
+  'ref_account' integer NOT NULL,
+  'ref_option' integer NOT NULL,
+  'comment' text,
+  PRIMARY KEY  ('id'),
+  UNIQUE ('ref_topic','ref_account','ref_option')
+);
+
 -- 
 -- コミュニティの画像
 -- 
@@ -989,7 +1019,7 @@ CREATE TABLE 'sns_rev_item' (
   'modify' timestamp NOT NULL,
   'ref_category' integer NOT NULL,
   'total' float,
-  'post' integer,
+  'post' integer default '0',
   'url' varchar(255) NOT NULL,
   'asin' varchar(128) NOT NULL,
   'name' text NOT NULL,
